@@ -1,21 +1,12 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
+#ifndef USE_EXTERNAL_SINGLEAPPLICATION
 #include "singleapplication.h"
+#else
+#include "QtSolutions/qtsingleapplication.h"
+#endif
+
 #include "src/cli/commandlineparser.h"
 #include "src/config/styleoverride.h"
 #include "src/core/capturerequest.h"
@@ -31,15 +22,47 @@
 #include <QTimer>
 #include <QTranslator>
 
+#define SPDLOG_ACTIVE_LEVEL SPDLOG_LEVEL_DEBUG
+#include "spdlog/spdlog.h"
+
 #if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
 #include "src/core/flameshotdbusadapter.h"
 #include "src/utils/dbusutils.h"
 #include <QDBusConnection>
 #include <QDBusMessage>
+#include <desktopinfo.h>
+#endif
+
+int waitAfterConnecting(int delay, QCoreApplication& app)
+{
+    QTimer t;
+    t.setInterval(delay + 1000 * 60 * 15); // 15 minutes timeout
+    QObject::connect(&t, &QTimer::timeout, qApp, &QCoreApplication::quit);
+    t.start();
+    // wait
+    return app.exec();
+}
+
+#ifdef Q_OS_LINUX
+// source: https://github.com/ksnip/ksnip/issues/416
+void wayland_hacks()
+{
+    // Workaround to https://github.com/ksnip/ksnip/issues/416
+    DesktopInfo info;
+    if (info.windowManager() == DesktopInfo::GNOME) {
+        qputenv("QT_QPA_PLATFORM", "xcb");
+    }
+}
 #endif
 
 int main(int argc, char* argv[])
 {
+#ifdef Q_OS_LINUX
+    wayland_hacks();
+#endif
+    spdlog::set_level(spdlog::level::debug); // Set global log level to debug
+    spdlog::set_pattern("[source %s] [function %!] [line %#] %v");
+
     // required for the button serialization
     // TODO: change to QVector in v1.0
     qRegisterMetaTypeStreamOperators<QList<int>>("QList<int>");
@@ -47,7 +70,11 @@ int main(int argc, char* argv[])
 
     // no arguments, just launch Flameshot
     if (argc == 1) {
+#ifndef USE_EXTERNAL_SINGLEAPPLICATION
         SingleApplication app(argc, argv);
+#else
+        QtSingleApplication app(argc, argv);
+#endif
         QApplication::setStyle(new StyleOverride);
 
         QTranslator translator, qtTranslator;
@@ -76,7 +103,7 @@ int main(int argc, char* argv[])
         app.setOrganizationName(QStringLiteral("flameshot"));
 
         auto c = Controller::getInstance();
-#if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
+#if not(defined(Q_OS_MACOS) || defined(Q_OS_WIN))
         new FlameshotDBusAdapter(c);
         QDBusConnection dbus = QDBusConnection::sessionBus();
         if (!dbus.isConnected()) {
@@ -92,7 +119,7 @@ int main(int argc, char* argv[])
         return app.exec();
     }
 
-#ifndef Q_OS_WIN
+#if not(defined(Q_OS_MACOS) || defined(Q_OS_WIN))
     /*--------------|
      * CLI parsing  |
      * ------------*/
@@ -151,6 +178,10 @@ int main(int argc, char* argv[])
       QStringLiteral("color-code"));
     CommandOption rawImageOption({ "r", "raw" },
                                  QObject::tr("Print raw PNG capture"));
+    CommandOption selectionOption(
+      { "g", "print-geometry" },
+      QObject::tr("Print geometry of the selection in the format W H X Y. Does "
+                  "nothing if raw is specified"));
     CommandOption screenNumberOption(
       { "n", "number" },
       QObject::tr("Define the screen to capture") + ",\n" +
@@ -216,7 +247,9 @@ int main(int argc, char* argv[])
     parser.AddArgument(configArgument);
     auto helpOption = parser.addHelpOption();
     auto versionOption = parser.addVersionOption();
-    parser.AddOptions({ pathOption, delayOption, rawImageOption }, guiArgument);
+    parser.AddOptions(
+      { pathOption, delayOption, rawImageOption, selectionOption },
+      guiArgument);
     parser.AddOptions({ screenNumberOption,
                         clipboardOption,
                         pathOption,
@@ -257,6 +290,7 @@ int main(int argc, char* argv[])
         QString pathValue = parser.value(pathOption);
         int delay = parser.value(delayOption).toInt();
         bool isRaw = parser.isSet(rawImageOption);
+        bool isSelection = parser.isSet(selectionOption);
         DBusUtils dbusUtils;
         CaptureRequest req(CaptureRequest::GRAPHICAL_MODE, delay, pathValue);
         uint id = req.id();
@@ -274,13 +308,10 @@ int main(int argc, char* argv[])
 
         if (isRaw) {
             dbusUtils.connectPrintCapture(sessionBus, id);
-            QTimer t;
-            t.setInterval(delay + 1000 * 60 * 15); // 15 minutes timeout
-            QObject::connect(
-              &t, &QTimer::timeout, qApp, &QCoreApplication::quit);
-            t.start();
-            // wait
-            return app.exec();
+            return waitAfterConnecting(delay, app);
+        } else if (isSelection) {
+            dbusUtils.connectSelectionCapture(sessionBus, id);
+            return waitAfterConnecting(delay, app);
         }
     } else if (parser.isSet(fullArgument)) { // FULL
         QString pathValue = parser.value(pathOption);
