@@ -1,24 +1,12 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #pragma once
 
 #include "src/widgets/capture/capturetoolbutton.h"
 #include <QSettings>
+#include <QStringList>
+#include <QVariant>
 #include <QVector>
 
 class ConfigHandler
@@ -30,11 +18,13 @@ public:
     void setButtons(const QVector<CaptureToolButton::ButtonType>&);
 
     QVector<QColor> getUserColors();
-    void setUserColors(const QVector<QColor>&);
 
-    QString savePathValue();
+    QString savePath();
     void setSavePath(const QString&);
 
+    bool savePathFixed();
+    void setSavePathFixed(bool);
+
     QColor uiMainColorValue();
     void setUIMainColor(const QColor&);
 
@@ -44,6 +34,9 @@ public:
     QColor drawColorValue();
     void setDrawColor(const QColor&);
 
+    void setFontFamily(const QString&);
+    const QString& fontFamily();
+
     bool showHelpValue();
     void setShowHelp(const bool);
 
@@ -53,6 +46,7 @@ public:
     bool desktopNotificationValue();
     void setDesktopNotification(const bool);
 
+    QString filenamePatternDefault();
     QString filenamePatternValue();
     void setFilenamePattern(const QString&);
 
@@ -60,36 +54,73 @@ public:
     void setDisabledTrayIcon(const bool);
 
     int drawThicknessValue();
-    void setdrawThickness(const int);
+    void setDrawThickness(const int);
+
+    int drawFontSizeValue();
+    void setDrawFontSize(const int);
 
     bool keepOpenAppLauncherValue();
     void setKeepOpenAppLauncher(const bool);
 
+    bool checkForUpdates();
+    void setCheckForUpdates(const bool);
+
     bool verifyLaunchFile();
     bool startupLaunchValue();
     void setStartupLaunch(const bool);
 
+    bool showStartupLaunchMessage();
+    void setShowStartupLaunchMessage(const bool);
+
     int contrastOpacityValue();
     void setContrastOpacity(const int);
 
-    bool closeAfterScreenshotValue();
-    void setCloseAfterScreenshot(const bool);
-
     bool copyAndCloseAfterUploadEnabled();
     void setCopyAndCloseAfterUploadEnabled(const bool);
+
+    bool historyConfirmationToDelete();
+    void setHistoryConfirmationToDelete(const bool save);
+
+    int uploadHistoryMaxSizeValue();
+    void setUploadHistoryMaxSize(const int);
+
     bool saveAfterCopyValue();
     void setSaveAfterCopy(const bool);
 
-    QString saveAfterCopyPathValue();
-    void setSaveAfterCopyPath(const QString&);
+    bool copyPathAfterSaveEnabled();
+    void setCopyPathAfterSaveEnabled(const bool);
 
-    void setDefaults();
+    bool useJpgForClipboard() const;
+    void setUseJpgForClipboard(const bool);
+    void setSaveAsFileExtension(const QString& extension);
+    QString getSaveAsFileExtension();
+
+    void setDefaultSettings();
     void setAllTheButtons();
 
+    void setIgnoreUpdateToVersion(const QString& text);
+    QString ignoreUpdateToVersion();
+
+    void setUndoLimit(int value);
+    int undoLimit();
+
+    QVector<QStringList> shortcuts();
+    void setShortcutsDefault();
+    bool setShortcut(const QString&, const QString&);
+    const QString& shortcut(const QString&);
+
     QString configFilePath() const;
 
+    void setValue(const QString& group,
+                  const QString& key,
+                  const QVariant& value);
+    QVariant& value(const QString& group, const QString& key);
+
 private:
+    QString m_strRes;
+    QVariant m_varRes;
     QSettings m_settings;
+    QVector<QStringList> m_shortcuts;
 
     bool normalizeButtons(QVector<int>&);
 
