@@ -1,19 +1,5 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #include "capturetoolbutton.h"
 #include "src/tools/capturetool.h"
@@ -21,7 +7,6 @@
 #include "src/utils/colorutils.h"
 #include "src/utils/confighandler.h"
 #include "src/utils/globalvalues.h"
-#include "src/widgets/capture/capturewidget.h"
 #include <QApplication>
 #include <QIcon>
 #include <QMouseEvent>
@@ -34,6 +19,8 @@
 CaptureToolButton::CaptureToolButton(const ButtonType t, QWidget* parent)
   : CaptureButton(parent)
   , m_buttonType(t)
+  , m_tool(nullptr)
+  , m_emergeAnimation(nullptr)
 {
     initButton();
     if (t == TYPE_SELECTIONINDICATOR) {
@@ -44,8 +31,24 @@ CaptureToolButton::CaptureToolButton(const ButtonType t, QWidget* parent)
     }
 }
 
+CaptureToolButton::~CaptureToolButton()
+{
+    if (m_tool) {
+        delete m_tool;
+        m_tool = nullptr;
+    }
+    if (m_emergeAnimation) {
+        delete m_emergeAnimation;
+        m_emergeAnimation = nullptr;
+    }
+}
+
 void CaptureToolButton::initButton()
 {
+    if (m_tool) {
+        delete m_tool;
+        m_tool = nullptr;
+    }
     m_tool = ToolFactory().CreateTool(m_buttonType, this);
 
     resize(GlobalValues::buttonBaseSize(), GlobalValues::buttonBaseSize());
@@ -115,27 +118,34 @@ void CaptureToolButton::setColor(const QColor& c)
 
 QColor CaptureToolButton::m_mainColor = ConfigHandler().uiMainColorValue();
 
-static std::map<CaptureToolButton::ButtonType, int> buttonTypeOrder{
+static std::map<CaptureToolButton::ButtonType, int> buttonTypeOrder
+{
     { CaptureToolButton::TYPE_PENCIL, 0 },
-    { CaptureToolButton::TYPE_DRAWER, 1 },
-    { CaptureToolButton::TYPE_ARROW, 2 },
-    { CaptureToolButton::TYPE_SELECTION, 3 },
-    { CaptureToolButton::TYPE_RECTANGLE, 4 },
-    { CaptureToolButton::TYPE_CIRCLE, 5 },
-    { CaptureToolButton::TYPE_MARKER, 6 },
-    { CaptureToolButton::TYPE_TEXT, 7 },
-    { CaptureToolButton::TYPE_PIXELATE, 8 },
-    { CaptureToolButton::TYPE_CIRCLECOUNT, 9 },
-    { CaptureToolButton::TYPE_SELECTIONINDICATOR, 10 },
-    { CaptureToolButton::TYPE_MOVESELECTION, 11 },
-    { CaptureToolButton::TYPE_UNDO, 12 },
-    { CaptureToolButton::TYPE_REDO, 13 },
-    { CaptureToolButton::TYPE_COPY, 14 },
-    { CaptureToolButton::TYPE_SAVE, 15 },
-    { CaptureToolButton::TYPE_EXIT, 16 },
-    { CaptureToolButton::TYPE_IMAGEUPLOADER, 17 },
-    { CaptureToolButton::TYPE_OPEN_APP, 18 },
-    { CaptureToolButton::TYPE_PIN, 19 },
+      { CaptureToolButton::TYPE_DRAWER, 1 },
+      { CaptureToolButton::TYPE_ARROW, 2 },
+      { CaptureToolButton::TYPE_SELECTION, 3 },
+      { CaptureToolButton::TYPE_RECTANGLE, 4 },
+      { CaptureToolButton::TYPE_CIRCLE, 5 },
+      { CaptureToolButton::TYPE_MARKER, 6 },
+      { CaptureToolButton::TYPE_TEXT, 7 },
+      { CaptureToolButton::TYPE_PIXELATE, 8 },
+      { CaptureToolButton::TYPE_CIRCLECOUNT, 9 },
+      { CaptureToolButton::TYPE_SELECTIONINDICATOR, 10 },
+      { CaptureToolButton::TYPE_MOVESELECTION, 11 },
+      { CaptureToolButton::TYPE_UNDO, 12 },
+      { CaptureToolButton::TYPE_REDO, 13 },
+      { CaptureToolButton::TYPE_COPY, 14 },
+      { CaptureToolButton::TYPE_SAVE, 15 },
+      { CaptureToolButton::TYPE_IMAGEUPLOADER, 16 },
+#if not defined(Q_OS_MACOS)
+      { CaptureToolButton::TYPE_OPEN_APP, 17 },
+      { CaptureToolButton::TYPE_EXIT, 18 }, { CaptureToolButton::TYPE_PIN, 19 },
+#else
+      { CaptureToolButton::TYPE_EXIT, 17 }, { CaptureToolButton::TYPE_PIN, 18 },
+#endif
+
+      { CaptureToolButton::TYPE_SIZEINCREASE, 20 },
+      { CaptureToolButton::TYPE_SIZEDECREASE, 21 },
 };
 
 int CaptureToolButton::getPriorityByButton(CaptureToolButton::ButtonType b)
@@ -164,7 +174,11 @@ QVector<CaptureToolButton::ButtonType>
       CaptureToolButton::TYPE_SAVE,
       CaptureToolButton::TYPE_EXIT,
       CaptureToolButton::TYPE_IMAGEUPLOADER,
+#if not defined(Q_OS_MACOS)
       CaptureToolButton::TYPE_OPEN_APP,
+#endif
       CaptureToolButton::TYPE_PIN,
       CaptureToolButton::TYPE_CIRCLECOUNT,
+      CaptureToolButton::TYPE_SIZEINCREASE,
+      CaptureToolButton::TYPE_SIZEDECREASE,
   };
